%%
%% This is file `dvipdfm.def',
%% and was *not* generated with the docstrip utility.
%%
%% It was hand edited from several docstripped def
%% files that are distributed with the Graphics Bundle
%%
%% A modified version of this file may be distributed, but it should
%% be distributed with a *different* name. Changed files must be
%% distributed *together with a complete and unchanged* distribution
%% of these files.
%%
%% In compliance with the above statement, the unmodified graphics
%% bundle is available from the same site you obtained this
%% modified file.  However, it is contained in a separate
%% tar file to conserve bandwidth.  You can get the
%% unmodified Graphics Bundle at
%%
%% http://odo.kettering.edu/dvipdfm/
%%
\ProvidesFile{dvipdfm.def}
        [1999/9/6 vx.x Driver-dependant file]
\def\c@lor@arg#1{%
  \dimen@#1\p@
  \ifdim\dimen@<\z@\dimen@\maxdimen\fi
  \ifdim\dimen@>\p@
    \PackageError{color}{Argument `#1' not in range [0,1]}\@ehd
  \fi}
\def\color@gray#1#2{%
  \c@lor@arg{#2}%
  \edef#1{gray #2}%
  }
\def\color@cmyk#1#2{\c@lor@@cmyk#2\@@#1}
\def\c@lor@@cmyk#1,#2,#3,#4\@@#5{%
  \c@lor@arg{#4}%
  \c@lor@arg{#1}%
  \c@lor@arg{#2}%
  \c@lor@arg{#3}%
  \edef#5{cmyk #1 #2 #3 #4}%
  }
\def\color@rgb#1#2{\c@lor@@rgb#2\@@#1}
\def\c@lor@@rgb#1,#2,#3\@@#4{%
  \c@lor@arg{#1}%
  \c@lor@arg{#2}%
  \c@lor@arg{#3}%
  \edef#4{rgb #1 #2 #3}%
  }
\def\color@RGB#1#2{\c@lor@@RGB#2\@@#1}
\def\c@lor@@RGB#1,#2,#3\@@#4{%
 \c@lor@RGB@rgb{#1}\@tempa
 \c@lor@RGB@rgb{#2}\@tempb
 \c@lor@RGB@rgb{#3}\@tempc
 \c@lor@@rgb\@tempa,\@tempb,\@tempc\@@#4%
  }
\def\c@lor@RGB@rgb#1#2{%
  \dimen@#1\p@
  \divide\dimen@\@cclv
  \edef#2{\strip@pt\dimen@}}
\def\color@hsb#1#2{\c@lor@@hsb#2\@@#1}
\def\c@lor@@hsb#1,#2,#3\@@#4{%
  \c@lor@arg{#1}%
  \c@lor@arg{#2}%
  \c@lor@arg{#3}%
  \edef#4{(not implemented yet) [ #1 #2 #3 ] }%
  }
\def\color@named#1#2{\c@lor@@named#2,,\@@#1}
\def\c@lor@@named#1,#2,#3\@@#4{%
  \@ifundefined{col@#1}%
    {\PackageError{color}{Undefined color `#1'}\@ehd}%
  {\edef#4{ #1}}%
  }
% \def\c@lor@to@ps#1 #2\@@{\csname c@lor@ps@#1\endcsname#2 \@@}
% \def\c@lor@ps@#1 #2\@@{TeXDict beginclude@ #1 end}
% \def\c@lor@ps@rgb#1\@@{#1 setrgbcolor}
% \def\c@lor@ps@hsb#1\@@{#1 sethsbcolor}
% \def\c@lor@ps@cmyk#1\@@{#1 setcmykcolor}
% \def\c@lor@ps@gray#1\@@{#1 setgray}
\def\current@color{gray 0}
\def\set@color{%
            \special{color push \current@color}\aftergroup\reset@color}
\def\reset@color{\special{color pop}}
\def\set@page@color{\special{background \current@color}}
\def\define@color@named#1#2{%
  \expandafter\let\csname col@#1\endcsname\@nnil}
\def\Ginclude@bmp#1{%
\message{<#1>}%
  \special{pdf: image width \the\Gin@req@width\space height
\the\Gin@req@height\space depth \the\z@ (#1)}}
\def\Ginclude@eps#1{%
 \message{<#1>}%
  \bgroup
  \def\@tempa{!}%
  \dimen@\Gin@req@width
  \dimen@ii.1bp%
  \divide\dimen@\dimen@ii
  \@tempdima\Gin@req@height
  \divide\@tempdima\dimen@ii
    \special{PSfile="#1"\space
      llx=\Gin@llx\space
      lly=\Gin@lly\space
      urx=\Gin@urx\space
      ury=\Gin@ury\space
      \ifx\Gin@scalex\@tempa\else rwi=\number\dimen@\space\fi
      \ifx\Gin@scaley\@tempa\else rhi=\number\@tempdima\space\fi
      \ifGin@clip clip\fi}%
  \egroup}
\def\Grot@start{%
\special{ps: gsave currentpoint currentpoint translate
\Grot@angle\space neg rotate neg exch neg exch translate}}
\def\Grot@end{\special{ps: currentpoint grestore moveto}}
\def\Gscale@start{\special{ps: gsave currentpoint currentpoint translate
\Gscale@x\space\Gscale@y\space scale neg exch neg exch translate}}
% \def\Gscale@start{\special{ps: currentpoint currentpoint translate
% \Gscale@x\space\Gscale@y\space scale neg exch neg exch translate}}
\def\Gscale@end{\special{ps: currentpoint grestore moveto}}
% \def\Gscale@end{\special{ps: currentpoint currentpoint translate
% 1 \Gscale@x\space div 1 \Gscale@x\space div scale neg exch neg exch translate}}
% \def\Gin@PS@raw#1{\special{ps: #1}}
% \def\Gin@PS@restored#1{\special{" #1}}
% \def\Gin@PS@literal@header#1{\AtBeginDvi{\special{! #1}}}
% \def\Gin@PS@file@header#1{\AtBeginDvi{\special{header=#1}}}
\def\Gin@extensions{.jpg,.jpeg,.pdf,.png}
\@namedef{Gin@rule@.jpg}#1{{bmp}{.bb}{#1}}
\@namedef{Gin@rule@.jpeg}#1{{bmp}{.bb}{#1}}
\@namedef{Gin@rule@.png}#1{{bmp}{.bb}{#1}}
\@namedef{Gin@rule@.pdf}#1{{eps}{.bb}{#1}}
\@namedef{Gin@rule@*}#1{{eps}{\Gin@ext}{#1}}
\endinput
%%
%% End of file `dvipdfm.def'.

